Module: Company

Defined in:
lib/company/version.rb,
lib/company/error.rb,
lib/company/phone.rb,
lib/company/account.rb,
lib/company/resource.rb,
lib/company/selection.rb,
lib/company/collection.rb,
lib/company/resources/job.rb,
lib/company/resources/lead.rb,
lib/company/resources/line.rb,
lib/company/resources/quote.rb,
lib/company/resources/visit.rb,
lib/company/errors/throttled.rb,
lib/company/resources/window.rb,
lib/company/collections/leads.rb,
lib/company/collections/visits.rb,
lib/company/resources/business.rb,
lib/company/resources/customer.rb,
lib/company/resources/location.rb,
lib/company/collections/windows.rb,
lib/company/resources/technician.rb

Overview

The vocabulary two platform gems share: an account opens a business and the records it holds.

Defined Under Namespace

Classes: Account, Business, Collection, Customer, Error, Job, Lead, Leads, Line, Location, Phone, Quote, Resource, Selection, Technician, Throttled, Visit, Visits, Window, Windows

Constant Summary collapse

VERSION =

The version of this gem, as RubyGems knows it.

'4.0.0'